@@ -43,6 +43,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     _node: T.ClassVar[T.Type[NodeType]]
     _edge_resolver_map: T.ClassVar[T.Dict[str, EdgeResolverType]]
+    _field_dependency_map: T.ClassVar[T.Dict[str, DependencyInfo]]
 
     _filter: str = PrivateAttr(None)
     _order_by: str = PrivateAttr(None)
@@ -61,9 +62,15 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     _fields_to_return: T.Set[str] = PrivateAttr(None)
     _fields_to_include: T.Set[str] = PrivateAttr(default_factory=set)
 
-    _field_dependency_map: T.ClassVar[T.Dict[str, DependencyInfo]] = {}
     """PROPERTIES"""
 
+    @classmethod
+    @property
+    def field_dependency_map(cls) -> T.Dict[str, DependencyInfo]:
+        if getattr(cls, "_field_dependency_map", None) is None:
+            cls._field_dependency_map = dict()
+        return cls._field_dependency_map
+
     @classmethod
     @property
     def _model_name(cls) -> str:
